FluidParam

Enum FluidParam 

#[repr(u8)]
pub enum FluidParam {
Show 57 variants T = 19, P = 20, Q = 21, QMass = 22, Tau = 23, Delta = 24, DMolar = 25, HMolar = 26, SMolar = 27, CpMolar = 28, Cp0Molar = 29, CvMolar = 30, UMolar = 31, GMolar = 32, HelmholtzMolar = 33, HMolarResidual = 34, SMolarResidual = 35, GMolarResidual = 36, HMolarIdealGas = 37, SMolarIdealGas = 38, UMolarIdealGas = 39, DMass = 40, HMass = 41, SMass = 42, CpMass = 43, Cp0Mass = 44, CvMass = 45, UMass = 46, GMass = 47, HelmholtzMass = 48, HMassIdealGas = 49, SMassIdealGas = 50, UMassIdealGas = 51, DynamicViscosity = 52, Conductivity = 53, SurfaceTension = 54, Prandtl = 55, SoundSpeed = 56, IsothermalCompressibility = 57, IsobaricExpansionCoefficient = 58, IsentropicExpansionCoefficient = 59, FundamentalDerivativeOfGasDynamics = 60, AlphaR = 61, DAlphaRDTauConstDelta = 62, DAlphaRDDeltaConstTau = 63, Alpha0 = 64, DAlpha0DTauConstDelta = 65, DAlpha0DDeltaConstTau = 66, D2Alpha0DDelta2ConstTau = 67, D3Alpha0DDelta3ConstTau = 68, BVirial = 69, CVirial = 70, DBVirialDT = 71, DCVirialDT = 72, Z = 73, PIP = 74, Phase = 85,
}
CoolProp fluids input/output parameters.

Examples

Conversion between &str:

use std::str::FromStr;

use rfluids::prelude::*;

assert_eq!(FluidParam::Conductivity.as_ref(), "conductivity");
assert_eq!(FluidParam::from_str("conductivity"), Ok(FluidParam::Conductivity));
assert_eq!(FluidParam::try_from("L"), Ok(FluidParam::Conductivity));

Conversion between u8:

use rfluids::prelude::*;

assert_eq!(u8::from(FluidParam::SMass), 42);
assert_eq!(FluidParam::try_from(42), Ok(FluidParam::SMass));

Conversion between f64:

use rfluids::prelude::*;

assert_eq!(FluidParam::try_from(42.0), Ok(FluidParam::SMass));

Conversion between FluidInputPair:

use rfluids::prelude::*;

assert_eq!(
    <(FluidParam, FluidParam)>::from(FluidInputPair::PT),
    (FluidParam::P, FluidParam::T)
);
assert_eq!(FluidInputPair::try_from((FluidParam::T, FluidParam::P)), Ok(FluidInputPair::PT));

See Also

Variants



T = 19

Temperature [K].



P = 20

Pressure [Pa].



Q = 21

Mole-based vapor quality [dimensionless, from 0 to 1].



QMass = 22

Mass-based vapor quality [dimensionless, from 0 to 1].



Tau = 23

Reciprocal reduced temperature = TCritical T [dimensionless].



Delta = 24

Reduced density = DMass/ DMassCritical [dimensionless].



DMolar = 25

Molar density [mol/mยณ].



HMolar = 26

Molar specific enthalpy [J/mol].



SMolar = 27

Molar specific entropy [J/mol/K].



CpMolar = 28

Molar specific heat at constant pressure [J/mol/K].



Cp0Molar = 29

Ideal gas molar specific heat at constant pressure [J/mol/K].



CvMolar = 30

Molar specific heat at constant volume [J/mol/K].



UMolar = 31

Molar specific internal energy [J/mol].



GMolar = 32

Molar specific Gibbs energy [J/mol].



HelmholtzMolar = 33

Molar specific Helmholtz energy [J/mol].



HMolarResidual = 34

Residual molar specific enthalpy [J/mol].



SMolarResidual = 35

Residual molar specific entropy [J/mol/K].



GMolarResidual = 36

Residual molar specific Gibbs energy [J/mol].



HMolarIdealGas = 37

Ideal gas molar specific enthalpy [J/mol].



SMolarIdealGas = 38

Ideal gas molar specific entropy [J/mol/K].



UMolarIdealGas = 39

Ideal gas molar specific internal energy [J/mol].



DMass = 40

Mass density [kg/mยณ].



HMass = 41

Mass specific enthalpy [J/kg].



SMass = 42

Mass specific entropy [J/kg/K].



CpMass = 43

Mass specific heat at constant pressure [J/kg/K].



Cp0Mass = 44

Ideal gas mass specific heat at constant pressure [J/kg/K].



CvMass = 45

Mass specific heat at constant volume [J/kg/K].



UMass = 46

Mass specific internal energy [J/kg].



GMass = 47

Mass specific Gibbs energy [J/kg].



HelmholtzMass = 48

Mass specific Helmholtz energy [J/kg].



HMassIdealGas = 49

Ideal gas mass specific enthalpy [J/kg].



SMassIdealGas = 50

Ideal gas mass specific entropy [J/kg/K].



UMassIdealGas = 51

Ideal gas mass specific internal energy [J/kg].



DynamicViscosity = 52

Dynamic viscosity [Paยทs].



Conductivity = 53

Thermal conductivity [W/m/K].



SurfaceTension = 54

Surface tension [N/m].



Prandtl = 55

Prandtl number [dimensionless].



SoundSpeed = 56

Sound speed [m/s].



IsothermalCompressibility = 57

Isothermal compressibility [1/Pa].



IsobaricExpansionCoefficient = 58

Isobaric expansion coefficient [1/K].



IsentropicExpansionCoefficient = 59

Isentropic expansion coefficient [dimensionless].



FundamentalDerivativeOfGasDynamics = 60

Fundamental derivative of gas dynamics [dimensionless].



AlphaR = 61

Residual Helmholtz energy contribution [dimensionless].



DAlphaRDTauConstDelta = 62

Derivative of residual Helmholtz energy contribution with Tau [dimensionless].



DAlphaRDDeltaConstTau = 63

Derivative of residual Helmholtz energy contribution with Delta [dimensionless].



Alpha0 = 64

Ideal gas Helmholtz energy contribution [dimensionless].



DAlpha0DTauConstDelta = 65

Derivative of ideal gas Helmholtz energy contribution with Tau [dimensionless].



DAlpha0DDeltaConstTau = 66

Derivative of ideal gas Helmholtz energy contribution with Delta [dimensionless].



D2Alpha0DDelta2ConstTau = 67

Second derivative of ideal gas Helmholtz energy contribution with Delta [dimensionless].



D3Alpha0DDelta3ConstTau = 68

Third derivative of ideal gas Helmholtz energy contribution with Delta [dimensionless].



BVirial = 69

Second virial coefficient [dimensionless].



CVirial = 70

Third virial coefficient [dimensionless].



DBVirialDT = 71

Derivative of second virial coefficient with T [dimensionless].



DCVirialDT = 72

Derivative of third virial coefficient with T [dimensionless].



Z = 73

Compressibility factor [dimensionless].



PIP = 74

Phase identification parameter [dimensionless].



Phase = 85

Phase index [dimensionless].

Implementations

Source

impl FluidParam

pub const fn from_repr(discriminant: u8) -> Option<FluidParam>

Try to create Self from the raw representation